@@ -1,6 +1,7 @@
 """
 Custom widgets used by the URL form fields.
 """
+from __future__ import unicode_literals
 import django
 from django.contrib import admin
 from django.contrib.admin.widgets import ForeignKeyRawIdWidget
@@ -9,7 +10,10 @@ from django.forms import widgets
 from django.forms.util import flatatt
 from django.forms.widgets import RadioFieldRenderer
 from django.template.defaultfilters import slugify
-from django.utils.encoding import force_unicode
+try:
+    from django.utils.encoding import force_unicode
+except ImportError:
+    from django.utils.encoding import force_text as force_unicode
 from django.utils.safestring import mark_safe
 
 
@@ -26,7 +30,7 @@ class HorizontalRadioFieldRenderer(RadioFieldRenderer):
     """
     def __init__(self, name, value, attrs, choices):
         extraclasses = 'radiolist inline'
-        if attrs.has_key('class'):
+        if 'class' in attrs:
             attrs['class'] += ' ' + extraclasses
         else:
             attrs['class'] = extraclasses
@@ -61,16 +65,7 @@ class AnyUrlWidget(widgets.MultiWidget):
         # Combine to list, ensure order of values list later.
         subwidgets = []
         for urltype in url_type_registry:
-            form_field = urltype.form_field
-            widget = form_field.widget
-            if isinstance(widget, type):
-                widget = widget()
-
-            # Widget instantiation needs to happen manually.
-            # Auto skip if choices is not an existing attribute.
-            if getattr(form_field, 'choices', None) and getattr(widget, 'choices', None):
-                widget.choices = form_field.choices
-
+            widget = urltype.get_widget()
             subwidgets.append(widget)
 
         subwidgets.insert(0, self.url_type_widget)
