@@ -1,6 +1,7 @@
 """
 Custom model fields to link to CMS content.
 """
+from django.utils import six
 from django.core.exceptions import ValidationError
 from django.core.validators import URLValidator
 from django.db import models
@@ -48,7 +49,7 @@ class AnyUrlField(models.CharField):
     _static_registry = UrlTypeRegistry()  # Also accessed by AnyUrlValue as internal field.
 
     def __init__(self, *args, **kwargs):
-        if not kwargs.has_key('max_length'):
+        if 'max_length' not in kwargs:
             kwargs['max_length'] = 300
         super(AnyUrlField, self).__init__(*args, **kwargs)
 
@@ -62,7 +63,7 @@ class AnyUrlField(models.CharField):
         that should be selectable in the URL field.
 
         :param ModelClass: The model to register.
-        :param form_field: The form field class used to render the field.
+        :param form_field: The form field class used to render the field. This can be a lambda for lazy evaluation.
         :param widget: The widget class, can be used instead of the form field.
         :param title: The title of the model, by default it uses the models ``verbose_name``.
         :param prefix: A custom prefix for the model in the serialized database format. By default it uses "appname.modelname".
@@ -76,7 +77,7 @@ class AnyUrlField(models.CharField):
         from any_urlfield.forms.fields import AnyUrlField as AnyUrlFormField
         kwargs['form_class'] = AnyUrlFormField
         kwargs['url_type_registry'] = self._static_registry
-        if kwargs.has_key('widget'):
+        if 'widget' in kwargs:
             del kwargs['widget']
         return super(AnyUrlField, self).formfield(**kwargs)
 
@@ -93,7 +94,7 @@ class AnyUrlField(models.CharField):
 
 
     def get_prep_value(self, value):
-        if isinstance(value, basestring):
+        if isinstance(value, six.string_types):
             # Happens with south migration
             return value
         elif value is None:
